@@ -21,8 +21,8 @@ Released under MIT license.
 """
 import sqlalchemy
 from tg.decorators import expose
-from tg.controllers import redirect
-from tw.api import Widget, CSSLink
+from tg.controllers import redirect, DecoratedController
+from tw.api import Widget, CSSLink, Link
 import pylons
 
 from dbsprockets.sprockets import Sprockets
@@ -30,6 +30,7 @@ from tg import TGController
 from dbsprockets.decorators import crudErrorCatcher, validate
 
 dbsprocketsCss = CSSLink(modname='dbsprockets', filename='dbmechanic/static/css/dbmechanic.css')
+dbMechanicFooterImg = Link(modname='dbsprockets', filename='dbmechanic/static/images/grad_blue.png')
 
 class BaseController(TGController):
     """Basis TurboGears controller class which is derived from
@@ -45,9 +46,8 @@ class BaseController(TGController):
         # Create a container to send widgets to the template. Only those sent
         # in here will have their resources automatically included in the
         # template
-        context.w = WidgetBunch()
-        context.css = dbsprocketsCss
         try:
+            dbMechanicFooterImg.inject()
             return TGController.__call__(self, environ, start_response)
         finally:
             pass
@@ -63,104 +63,94 @@ class DBMechanic(BaseController):
         self.controller = controller
 
         #commonly used views
-        sprocket = self.sprockets['databaseView']
-        self.databaseValue = sprocket.session.getValue()
+        sprocket = self.sprockets['database_view']
+        self.databaseValue = sprocket.session.get_value()
         self.databaseView  = sprocket.view.widget
         self.databaseDict  = dict(databaseValue=self.databaseValue, controller=self.controller)
         BaseController.__init__(self, *args, **kwargs)
 
     @expose('genshi:dbsprockets.dbmechanic.frameworks.tg2.templates.index')
     def index(self):
+        dbsprocketsCss.inject()
         pylons.c.databaseView  = self.databaseView
         pylons.c.mainView=Widget("widget")
         return self.databaseDict
 
     @expose('genshi:dbsprockets.dbmechanic.frameworks.tg2.templates.edit')
-    def tableDef(self, tableName):
-        sprocket  = self.sprockets['tableDef__'+tableName]
+    def tableDef(self, table_name):
+        dbsprocketsCss.inject()
+        sprocket  = self.sprockets['table_def__'+table_name]
         pylons.c.mainView  = sprocket.view.widget
         pylons.c.databaseView  = self.databaseView
-        mainValue = sprocket.session.getValue()
-        d = dict(tableName=tableName, mainValue=mainValue)
+        mainValue = sprocket.session.get_value()
+        d = dict(table_name=table_name, mainValue=mainValue)
         d.update(self.databaseDict)
         return d
 
     @expose('genshi:dbsprockets.dbmechanic.frameworks.tg2.templates.tableView')
-    def tableView(self, tableName, page=1, recordsPerPage=25, **kw):
+    def tableView(self, table_name, page=1, recordsPerPage=25, **kw):
+        dbsprocketsCss.inject()
         #this should probably be a decorator
         page = int(page)
         recordsPerPage = int(recordsPerPage)
 
-        sprocket  = self.sprockets['tableView__'+tableName]
+        sprocket  = self.sprockets['table_view__'+table_name]
         pylons.c.mainView  = sprocket.view.widget
         pylons.c.databaseView  = self.databaseView
-        mainValue = sprocket.session.getValue(values=kw, page=page, recordsPerPage=recordsPerPage)
-        mainCount = sprocket.session.getCount(values=kw,)
-        d = dict(tableName=tableName, mainValue=mainValue, mainCount=mainCount)
+        mainValue = sprocket.session.get_value(values=kw, page=page, recordsPerPage=recordsPerPage)
+        main_count = sprocket.session.get_count(values=kw,)
+        d = dict(table_name=table_name, mainValue=mainValue, main_count=main_count)
         d.update(self.databaseDict)
         d['page'] = page
         d['recordsPerPage'] = recordsPerPage
         return d
 
     @expose('genshi:dbsprockets.dbmechanic.frameworks.tg2.templates.edit')
-    def addRecord(self, tableName, **kw):
-        sprocket = self.sprockets['addRecord__'+tableName]
+    def addRecord(self, table_name, **kw):
+        dbsprocketsCss.inject()
+        sprocket = self.sprockets['add_record__'+table_name]
         pylons.c.mainView  = sprocket.view.widget
         pylons.c.databaseView  = self.databaseView
-        mainValue = sprocket.session.getValue(values=kw)
-        d = dict(tableName=tableName, mainValue=mainValue)
+        mainValue = sprocket.session.get_value(values=kw)
+        d = dict(table_name=table_name, mainValue=mainValue)
         d.update(self.databaseDict)
         return d
 
     @expose('genshi:dbsprockets.dbmechanic.frameworks.tg2.templates.edit')
-    def editRecord(self, tableName, **kw):
-        sprocket = self.sprockets['editRecord__'+tableName]
+    def editRecord(self, table_name, **kw):
+        dbsprocketsCss.inject()
+        sprocket = self.sprockets['edit_record__'+table_name]
         pylons.c.mainView  = sprocket.view.widget
         pylons.c.databaseView  = self.databaseView
-        mainValue = sprocket.session.getValue(values=kw)
-        d = dict(tableName=tableName, mainValue=mainValue)
+        mainValue = sprocket.session.get_value(values=kw)
+        d = dict(table_name=table_name, mainValue=mainValue)
         d.update(self.databaseDict)
         return d
 
-    def createRelationships(self, tableName, params):
-        #this might become a decorator
-        #check to see if the table is a many-to-many table first
-        if tableName in self.provider.getManyToManyTables():
-            return
-        #right now many-to-many only supports single primary keys
-        pk=self.provider.getPrimaryKeys(tableName)
-        assert len(pk)==1
-        id = params[pk[0]]
-        relationships = {}
-        for key, value in params.iteritems():
-            if key.startswith('many_many_'):
-                relationships.setdefault(key[10:], []).append(value)
-        for key, value in relationships.iteritems():
-            self.provider.setManyToMany(tableName, id, key, value)
-
     @expose()
     @validate(error_handler=editRecord)
     @crudErrorCatcher(errorType=sqlalchemy.exceptions.IntegrityError, error_handler='editRecord')
     @crudErrorCatcher(errorType=sqlalchemy.exceptions.ProgrammingError, error_handler='editRecord')
-    def edit(self, tableName, *args, **kw):
+    @crudErrorCatcher(errorType=sqlalchemy.exceptions.DataError, error_handler='editRecord')
+    def edit(self, table_name, *args, **kw):
         params = pylons.request.params.copy()
-        self.createRelationships(tableName, params)
+        self.provider.create_relationships(table_name, params)
 
-        self.provider.edit(tableName, values=kw)
-        redirect(self.controller+'/tableView/'+tableName)
+        self.provider.edit(table_name, values=kw)
+        redirect(self.controller+'/tableView/'+table_name)
 
     @expose()
     @validate(error_handler=addRecord)
     @crudErrorCatcher(errorType=sqlalchemy.exceptions.IntegrityError, error_handler='addRecord')
     @crudErrorCatcher(errorType=sqlalchemy.exceptions.ProgrammingError, error_handler='addRecord')
-    def add(self, tableName, **kw):
+    def add(self, table_name, **kw):
         params = pylons.request.params.copy()
-        self.createRelationships(tableName, params)
+        self.provider.create_relationships(table_name, params)
 
-        self.provider.add(tableName, values=kw)
-        redirect(self.controller+'/tableView/'+tableName)
+        self.provider.add(table_name, values=kw)
+        redirect(self.controller+'/tableView/'+table_name)
 
     @expose()
-    def delete(self, tableName, **kw):
-        self.provider.delete(tableName, values=kw)
-        redirect(self.controller+'/tableView/'+tableName)
+    def delete(self, table_name, **kw):
+        self.provider.delete(table_name, values=kw)
+        redirect(self.controller+'/tableView/'+table_name)
