@@ -11,12 +11,13 @@ from pprint import pprint
 from nose.tools import eq_
 
 app = None
+session = None
 
 def setup():
-    global app
+    global app, session
     here_dir = os.path.dirname(os.path.abspath(__file__))
     proj_dir = os.path.join(here_dir, 'TG2TestApp')
-    
+
     pkg_resources.working_set.add_entry(proj_dir)
 
     from tg2testapp.model import DBSession, metadata, User, Group
@@ -30,9 +31,9 @@ def setup():
     user.user_name = u'asdf'
     user.email = u"asdf@asdf.com"
     user.password = u"asdf"
-    
+
     session.save(user)
-    
+
     for i in range (50):
         group = Group()
         group.group_name=unicode(i)
@@ -40,9 +41,8 @@ def setup():
         user.groups.append(group)
 
     session.save(user)
-    session.commit()
     session.flush()
-    
+
 def teardown():
     from tg2testapp.model import User, Group, DBSession as session, metadata
     del metadata
@@ -50,17 +50,18 @@ def teardown():
 class TestDBMechanic:
     def setup(self):
         from tg2testapp.model import users_table, user_group_table, groups_table
-        users_table.delete().execute()
-        groups_table.delete().execute()
-        user_group_table.delete().execute()
-        
+        #users_table.delete().execute()
+        #groups_table.delete().execute()
+        #user_group_table.delete().execute()
+    def teardown(self):
+        session.rollback()
+
     def testDatabaseView(self):
         resp = app.get('/dbmechanic')
         s =  resp.body
         assert """<div class="tablelabelwidget">
 <a href="/dbmechanic/tableView/town_table">town_table</a>
 </div>
-<input type="hidden" name="dbsprockets_id" class="hiddenfield" id="databaseView_dbsprockets_id" value="test_tabletg_grouppermissionvisituser_groupvisit_identitygroup_permissiontg_usertown_table">
 </div>
       </div>
       <div class="mainView" style="bg-color:#ffffff;">
@@ -74,7 +75,7 @@ class TestDBMechanic:
   </div>
 </body>
 </html>""" in s, "actual: %s"%s
-    
+
     def testTableDef(self):
         resp = app.get('/dbmechanic/tableDef/tg_user')
         value =  resp.body
@@ -86,10 +87,9 @@ class TestDBMechanic:
     DateTime(timezone=False)
     </td>
 </tr>
-<input type="hidden" name="dbsprockets_id" class="hiddenfield" id="tableDef__tg_user_dbsprockets_id" value="">
 </table>
       </div>""" in value, value
-        
+
     def testTableView(self):
         from tg2testapp.model import User, Group, DBSession as session
         u = User()
@@ -102,7 +102,7 @@ class TestDBMechanic:
         group.display_name=u"group"
         session.save(group)
         session.flush()
-        
+
         resp = app.get('/dbmechanic/tableView/tg_user')
         value =  resp.body
         assert """<thead>
@@ -132,7 +132,7 @@ class TestDBMechanic:
             <td><a href="/dbmechanic/editRecord/tg_user?user_id=1">"""
         """edit</a>|<a href="/dbmechanic/delete/tg_user?user_id=1">delete</a></td><td>1</td><td>user2</td>"""
         """<td></td><td></td><td>******</td><td>""" in value, value
-        
+
     def testAddRecord(self):
         resp = app.get('/dbmechanic/addRecord/tg_user')
         value =  resp.body
@@ -150,7 +150,7 @@ class TestDBMechanic:
             </td>
         </tr>
     </table>"""
-        
+
     def testEditRecord(self):
         from tg2testapp.model import User, Group, DBSession as session
         u = User()
@@ -167,8 +167,8 @@ class TestDBMechanic:
         value =  resp.body
         assert """<td>
                 <div>
-    <input type="text" id="editRecord__tg_user_created" class="dbsprocketscalendardatetimepicker" name="created" value="2007-12-21 20:45:00" />
-    <input type="button" id="editRecord__tg_user_created_trigger" class="date_field_button" value="Choose" />
+    <input type="text" id="edit_record__tg_user_created" class="dbsprocketscalendardatetimepicker" name="created" value="2007-12-21 20:45:00" />
+    <input type="button" id="edit_record__tg_user_created_trigger" class="date_field_button" value="Choose" />
 </div>
             </td>
         </tr><tr class="even">
@@ -188,30 +188,30 @@ class TestDBMechanic:
         resp = app.get('/dbmechanic/add/tg_user', params=dict(user_id=None,
                                                               user_name=u'new_user',
                                                               email_address=u'new@user.com',
-                                                              dbsprockets_id=u'addRecord__tg_user'))
+                                                              dbsprockets_id=u'add_record__tg_user'))
         #actual =  resp.follow().namespace
         actual = resp.namespace
 #        eq_({}, value)
-        
-        expected = {'controller': '/dbmechanic', 
-                    #'context': <paste.registry.StackedObjectProxy object at 0x2225f90>, 
-                    #'recordsPerPage': 25, 
-                    'tableName': 'tg_user', 
-                    #'mainCount': 1, 
+
+        expected = {'controller': '/dbmechanic',
+                    #'context': <paste.registry.StackedObjectProxy object at 0x2225f90>,
+                    #'recordsPerPage': 25,
+                    'table_name': 'tg_user',
+                    #'main_count': 1,
                     #'page': 1
                     }
-        mainValue ={u'town': None, 
-                    u'user_id': 1, 
-#                           u'created': datetime.datetime(2008, 2, 23, 11, 59, 35, 144897), 
-                    u'email_address': u'new@user.com', 
-                    'tg_groups': '', 
-                    u'display_name': None, 
-                    u'password': '******', 
+        mainValue ={u'town': None,
+                    u'user_id': 1,
+#                           u'created': datetime.datetime(2008, 2, 23, 11, 59, 35, 144897),
+                    u'email_address': u'new@user.com',
+                    'tg_groups': '',
+                    u'display_name': None,
+                    u'password': '******',
                     u'user_name': u'new_user'}
-        
+
         for key, value in expected.iteritems():
             yield eq_, value, actual[key]
-        
+
         #actualRow = actual['mainValue'][0]
 
 #        for key, value in mainValue.iteritems():
@@ -224,46 +224,45 @@ class TestDBMechanic:
         u.password = u'asdf'
         u.email_address=u"test@edit.com"
         session.save(u)
-        session.commit()
         session.flush()
         u_id = str(u.user_id)
         resp = app.get('/dbmechanic/editRecord/tg_user?user_id='+u_id)
         value =  resp.body
-        resp = app.get('/dbmechanic/edit/tg_user', params=dict(user_id=u_id, 
+        resp = app.get('/dbmechanic/edit/tg_user', params=dict(user_id=u_id,
                                                               user_name=u'new_username',
                                                               email_address=u'newemail@user.com',
-                                                              dbsprockets_id=u'editRecord__tg_user'
+                                                              dbsprockets_id=u'edit_record__tg_user'
                                                           ))
-        actual =  resp.follow().namespace
-        expected = {'controller': '/dbmechanic', 
-                    'recordsPerPage': 25, 
-                    'tableName': 'tg_user', 
-                    'mainCount': 1, 
+        actual =  resp.namespace
+        expected = {'controller': '/dbmechanic',
+                    'recordsPerPage': 25,
+                    'table_name': 'tg_user',
+                    'main_count': 1,
                     'page': 1}
-        mainValue ={u'town': None, 
-                    u'user_id': 1, 
-#                           u'created': datetime.datetime(2008, 2, 23, 11, 59, 35, 144897), 
-                    u'email_address': u'newemail@user.com', 
-                    'tg_groups': '', 
-                    u'display_name': None, 
-                    u'password': '******', 
+        mainValue ={u'town': None,
+                    u'user_id': 1,
+#                           u'created': datetime.datetime(2008, 2, 23, 11, 59, 35, 144897),
+                    u'email_address': u'newemail@user.com',
+                    'tg_groups': '',
+                    u'display_name': None,
+                    u'password': '******',
                     u'user_name': u'new_username'}
-        
+
         for key, value in expected.iteritems():
             yield eq_, value, actual[key]
         actualRow = actual['mainValue'][0]
 
         for key, value in mainValue.iteritems():
             yield eq_, value, actualRow[key]
-            
-    def testCreateRelationships(self):
+
+    def test_createRelationships(self):
         from tg2testapp.model import User, Group, DBSession as session
         u = User()
         u.user_name=u'userCreateRel'
         u.password = u'asdf'
         u.email_address=u"create@relationships.com"
         session.save(u)
-        session.commit()
+        session.flush()
         group = Group()
         group.group_name=u"create_rel_group"
         group.display_name=u"group"
@@ -271,17 +270,17 @@ class TestDBMechanic:
         session.flush()
         u_id = str(u.user_id)
         #add group 1
-        resp = app.get('/dbmechanic/edit/tg_user', params=dict(user_id=u_id, 
+        resp = app.get('/dbmechanic/edit/tg_user', params=dict(user_id=u_id,
                                                         user_name=u'new_username',
                                                         email_address=u'newemail@user.com',
-                                                        dbsprockets_id=u'editRecord__tg_user',
+                                                        dbsprockets_id=u'edit_record__tg_user',
                                                         many_many_tg_group="1",
                                                           ))
 
-    def testCreateRelationshipsManyMany(self):
+    def test_createRelationshipsManyMany(self):
         from tg2testapp.model import user_group_table
         user_group_table.insert(values=dict(user_id=1, group_id=2)).execute()
-        resp = app.get('/dbmechanic/edit/user_group', params=dict(dbsprockets_id='editRecord__user_group', user_id=1, group_id=2))
+        resp = app.get('/dbmechanic/edit/user_group', params=dict(dbsprockets_id='edit_record__user_group', user_id=1, group_id=2))
 
     def testEdit(self):
         from tg2testapp.model import User, Group, DBSession as session
@@ -290,9 +289,8 @@ class TestDBMechanic:
         u.password = u'asdf'
         u.email_address=u"test@edit.com"
         session.save(u)
-        session.commit()
         session.flush()
         u_id = str(u.user_id)
         resp = app.get('/dbmechanic/delete/tg_user?user_id='+u_id)
-        
-        
+
+
