@@ -21,34 +21,35 @@ Released under MIT license.
 
 class IProvider:
     #table information stuff
-    def getTables(self):
-        """()->[list of tablesNames] 
+    def get_tables(self):
+        """()->[list of tablesNames]
         get a list of tables from the database"""
         raise NotImplementedError
-    def getTable(self, name):
+    def get_table(self, name):
         """(name) -> sqlalchemy.schema.Table
         get the table definition with the given table name
         """
         raise NotImplementedError
-    def getColumns(self, tableName):
-        """(name) -> [list of columnNames]
+    def get_columns(self, table_name):
+        """(name) -> [list of column_names]
         get the column names given the table name
         """
         raise NotImplementedError
-    def getColumn(self, tableName, name):
-        """(tableName, name) -> sqlalchemy.schema.Column
+    def get_column(self, table_name, name):
+        """(table_name, name) -> sqlalchemy.schema.Column
         get the column definition givcen the tablename and column name.
         """
         raise NotImplementedError
-    def getPrimaryKeys(self, tableName):
+    def get_primary_keys(self, table_name):
+        raise NotImplementedError
+    def get_server_default(self,table_name, key):
         raise NotImplementedError
-
     #crud stuff
-    def select(self, tableName, **kw):
+    def select(self, table_name, **kw):
         raise NotImplementedError
-    def add(self, tableName=None, **kw):
+    def add(self, table_name=None, **kw):
         raise NotImplementedError
-    def edit(self, tableName=None, **kw):
+    def edit(self, table_name=None, **kw):
+        raise NotImplementedError
+    def is_nullable_field(self,field):
         raise NotImplementedError
-    def isNullableField(self,field):
-        raise NotImplementedError
\ No newline at end of file
