@@ -6,7 +6,7 @@ from sqlalchemy.orm import scoped_session, sessionmaker
 
 # Global session manager.  Session() returns the session object
 # appropriate for the current web request.
-Session = scoped_session(sessionmaker(autoflush=True, transactional=True))
+Session = scoped_session(sessionmaker(autoflush=True, autocommit=False))
 
 # The identity schema.
 visits_table = Table('visit', metadata,
@@ -73,6 +73,10 @@ user_reference_table=Table('user_reference', metadata,
     Column('user_id',Integer,ForeignKey('tg_user.user_id'),primary_key=True),
     mysql_engine='innodb',
 )
+no_auto_increment_table=Table('no_auto_increment', metadata,
+    Column('no_auto_increment_id',Integer,autoincrement=False,primary_key=True),
+    mysql_engine='innodb',
+)
 test_table = Table('test_table', metadata,
                    Column('id', Integer, primary_key=True),
                    Column('created', DateTime, default=datetime.now),
@@ -104,7 +108,7 @@ test_table = Table('test_table', metadata,
                    Column('Unicode',      Unicode(200)  ),
                    Column('VARCHAR',      VARCHAR(200)  ),
                    Column('Password',     String(20)    ),
-)                  
+)
 
 class Example(object):
     pass
