@@ -7,50 +7,45 @@ from dbsprockets.metadata import Metadata, MetadataError, DatabaseMetadata, Fiel
 from dbsprockets.saprovider import SAProvider
 from dbsprockets.test.base import sortedTableList
 from dbsprockets.iprovider import IProvider
+from dbsprockets.test.base import setupDatabase, DBSprocketsTest
 
 import model
 from model import *
+session = None
+engine = None
+connect = None
+trans = None
 
 def setup():
-    engine = create_engine('sqlite://')
-    metadata.bind = engine
-    metadata.create_all(bind=engine)
-    Session = sessionmaker(bind=engine, autoflush=True, transactional=True)
-    session = Session()
-    
-    u = User()
-    u.user_name=u'asdf'
-    u.password = u'asdf'
-    u.email=u"asdf@asdf.com"
-    session.save(u)
-    g = Group(group_name=u"group", display_name=u"group")
-    session.save(g)
-    session.flush()
+    global session, engine, connect, trans
+    session, engine, connect = setupDatabase()
+#    trans = engine.begin()
 
 provider = SAProvider(metadata)
 
-class TestMetadata:
+class TestMetadata(DBSprocketsTest):
     obj = Metadata
     provider = IProvider()
-    
+
     def setup(self):
+        super(TestMetadata, self).setup()
         self.metadata = self.obj(self.provider)
 
-    def testCreate(self):
+    def test_create(self):
         pass
-    
+
     @raises(TypeError)
     def _create(self, arg1):
         Metadata(arg1)
-        
-    def testCreateBad(self):
+
+    def test_create_bad(self):
         badInput = ((), [], {}, 'a', 1, 1.2)
         for input in badInput:
             yield self._create, input
 
     @raises(NotImplementedError)
     def testPrimaryKeys(self):
-        self.metadata.primaryKeys()
+        self.metadata.primary_keys()
     @raises(NotImplementedError)
     def testSetItem(self):
         self.metadata['asdf'] = 'asdf'
@@ -62,10 +57,11 @@ class TestMetadata:
         value = self.metadata.keys()
     @raises(NotImplementedError)
     def testAutoIncrementFields(self):
-        value = self.metadata.autoIncrementFields
+        value = self.metadata.auto_increment_fields
 
 class TestDatabaseMetadata(TestMetadata):
     def setup(self):
+        super(TestDatabaseMetadata, self).setup()
         self.metadata = DatabaseMetadata(provider)
     def testKeys(self):
         tables = sorted(self.metadata.keys())
@@ -82,52 +78,53 @@ class TestDatabaseMetadata(TestMetadata):
     def testSetItemBad(self):
         self.metadata['test_table'] = '1234'
     def testPrimaryKeys(self):
-        assert [] == self.metadata.primaryKeys()
+        assert [] == self.metadata.primary_keys()
     def testGetForeignKeys(self):
         metadata = DatabaseMetadata(provider)
-        pks = metadata.foreignKeys
+        pks = metadata.foreign_keys
         assert [] == pks, "%s"%pks
-   
+
 class TestFieldsMetadata(TestMetadata):
     def setup(self):
+        super(TestFieldsMetadata, self).setup()
         self.metadata = FieldsMetadata(provider, 'test_table')
-        
+
     def testGetItem(self):
         field = self.metadata['id']
         assert field.name == 'id'
-    
+
     def testAutoIncrementFields(self):
         #this is expected input for SA, but I think we can do better
-        value = self.metadata.autoIncrementFields
-        eq_(value, ['id', 'created', 'BLOB', 'BOOLEAN_', 'Binary', 
-                    'Boolean', 'CHAR', 'CLOB', 'DATE_', 'DATETIME_', 
-                    'DECIMAL', 'Date', 'DateTime', 'FLOAT_', 
-                    'Float', 'INT', 'Integer', 'Numeric', 'PickleType', 
-                    'SMALLINT', 'SmallInteger', 'String', 'TEXT', 'TIME_', 
+        value = self.metadata.auto_increment_fields
+        eq_(value, ['id', 'created', 'BLOB', 'BOOLEAN_', 'Binary',
+                    'Boolean', 'CHAR', 'CLOB', 'DATE_', 'DATETIME_',
+                    'DECIMAL', 'Date', 'DateTime', 'FLOAT_',
+                    'Float', 'INT', 'Integer', 'Numeric', 'PickleType',
+                    'SMALLINT', 'SmallInteger', 'String', 'TEXT', 'TIME_',
                     'Time', 'TIMESTAMP', 'Unicode', 'VARCHAR', 'Password'])
 
     @raises(KeyError)
     def testGetItemKeyError(self):
         self.metadata['asdf']
-        
+
     def testSetItem(self):
         self.metadata['asdf'] = '1234'
         assert self.metadata['asdf'] == '1234'
-        
+
     @raises(MetadataError)
     def testSetItemBad(self):
         self.metadata['id'] = '1234'
-    
+
     def testKeys(self):
         self.metadata['asdf'] = '1234'
         keys = sorted(self.metadata.keys())
         assert keys ==['BLOB', 'BOOLEAN_', 'Binary', 'Boolean', 'CHAR', 'CLOB', 'DATETIME_', 'DATE_', 'DECIMAL', 'Date', 'DateTime', 'FLOAT_', 'Float', 'INT', 'Integer', 'Numeric', 'Password', 'PickleType', 'SMALLINT', 'SmallInteger', 'String', 'TEXT', 'TIMESTAMP', 'TIME_', 'Time', 'Unicode', 'VARCHAR', 'asdf', 'created', 'id'], "actual: %s"%keys
-        
+
     def testPrimaryKeys(self):
-        pks = self.metadata.primaryKeys()
+        pks = self.metadata.primary_keys()
         assert ['id',] == pks, "%s"%pks
 
     def testGetForeignKeys(self):
         metadata = FieldsMetadata(provider, 'tg_user')
-        pks = metadata.foreignKeys
+        pks = metadata.foreign_keys
         assert ['town',] == pks, "%s"%pks
