@@ -8,13 +8,13 @@ class testView:
     def setup(self):
         provider = IProvider()
 #        metadata = Metadata(provider)
-        viewConfig = ViewConfig(provider, '')
-        
-        self.view = View(Widget(), viewConfig)
-        
-    def testCreate(self):
+        view_config = ViewConfig(provider, '')
+
+        self.view = View(Widget(), view_config)
+
+    def test_create(self):
         pass
-    
+
     def testDisplay(self):
         s = self.view.widget(value={})
         assert s == None, s
\ No newline at end of file
