@@ -4,22 +4,21 @@ from dbsprockets.metadata import Metadata, NotFoundError
 from dbsprockets.iprovider import IProvider
 
 class DummyMetadata(Metadata):
-    def _doKeys(self):
+    def _do_keys(self):
         return []
-    
+
 
 class DummyViewConfig(ViewConfig):
-    metadataType = DummyMetadata
-    
+    metadata_type = DummyMetadata
+
 class testViewFactory:
     def setup(self):
         provider = IProvider()
-        self.viewFactory = ViewFactory()
-        self.viewConfig = DummyViewConfig(provider, 'test_table')
-        
-    def testCreateObj(self):
+        self.view_factory = ViewFactory()
+        self.view_config = DummyViewConfig(provider, 'test_table')
+
+    def test_createObj(self):
         pass
-    
-    def testCreate(self):
-        view  = self.viewFactory.create(self.viewConfig)
-    
\ No newline at end of file
+
+    def test_create(self):
+        view  = self.view_factory.create(self.view_config)
