@@ -16,6 +16,6 @@ Original Version by Christopher Perkins 2007
 Released under MIT license.
 """
 class View:
-    def __init__(self, widget, viewConfig):
+    def __init__(self, widget, view_config):
         self.widget = widget
-        self.viewConfig = viewConfig
\ No newline at end of file
+        self.view_config = view_config
